@@ -155,20 +155,29 @@ def main(argv):
                 print('python -m artify -c deltav -t <version_change> -a <architecture_type>')
                 print("Or")
                 print("python -m artify --command deltav --type <version_change> --archtype <architecture_type>")
-                print("")
-                print("e.g --archtype npm, gradle, maven, dotnet, netcore")
-                print("\nOptional arguments: ")
-                print("-b, --branch        Branch to commit code changes. Default: develop")
+                print("Mandatory argument(s): ")
+                print("-t, --type          Type of version change: major, minor, patch")
                 print("e.g --type major    1.0.0.0 => 2.0.0.0")
                 print("e.g --type minor    1.0.0.0 => 1.1.0.0")
                 print("e.g --type patch    1.0.0.0 => 1.0.1.0")
                 print("e.g --type build    1.0.0.0 => 1.0.0.1   Experimental")
+                
+                print("e.g --archtype npm, gradle, maven, flutter, dotnet, netcore")
+                print("\nOptional arguments: ")
+                print("-b, --branch        Branch to commit code changes. Default: develop")
+               
                 return sys.exit(0)
+            elif arg == 'create':
+                print('')
+                print('python -m artify -c create -f <template_file>')
+                print("Mandatory argument(s): ")
+                print('-f, --file    Template file to create e.g manifest, gitlabci')
             else:
                 print('python -m artify --help nexus        Help on how to deploy to Nexus Repository')
                 print('python -m artify --help deploy       Help on how to deploy to AWX host')
                 print('python -m artify --help syncrepo     Help on how to commit and push code to repository')
-                print('python -m artify --help deltav      Help on how to change version number')
+                print('python -m artify --help deltav       Help on how to change version number')
+                print("python -m artify --help create       Help on how to generate template files")
                 return sys.exit(0)
         elif opt == "--debug":
             debug = 1
@@ -310,6 +319,7 @@ def main(argv):
             nexus.upload_nexus_maven()
         else:
             print("Invalid nexus format entered")
+            return sys.exit(2)
             
     elif action == 'deltav':
         change_version.modify_version()
