@@ -1,6 +1,7 @@
 import __main__
 import fileinput
 import re
+from glob import glob
 
 path = __main__.os.path.abspath(__main__.os.getcwd()) 
 
@@ -55,7 +56,7 @@ def get_version(filename):
                     result = 0
                     versionstr = line
                     break                
-                if __main__.arch_type == 'dotnet' and re.search(r'<AssemblyVersion>', line):
+                if __main__.arch_type == 'dotnet' and re.search(r'assembly: AssemblyVersion', line):
                     result = 0
                     versionstr = line
                     break                    
@@ -113,13 +114,14 @@ def get_version(filename):
     elif __main__.arch_type == 'dotnet':
         print("Architecture::: .NET/C# : MSbuild")
         strip_version = versionstr.strip()
-        version_string = re.sub('<[^<]+>', '', strip_version)
-        version_string = version_string.strip()
+        clean_ver1 = re.sub('assembly: AssemblyVersion', '', strip_version)
+        clean_ver2 = re.sub('[\[(")\]]*', '', clean_ver1)
+        version_string = re.sub("[']", '', clean_ver2.strip())
         
     elif __main__.arch_type == 'netcore':
         print("Architecture::: .NetCore/C# ")
         strip_version = versionstr.strip()
-        version_string = re.sub('<[^<]+>', '', strip_version)
+        version_string = re.sub('<[(^<]+>', '', strip_version)
         version_string = version_string.strip()
     
     return version_string    
@@ -225,7 +227,8 @@ def process_version(versionstr):
 def replace_version(filename, search_text, replacement_text):
     with fileinput.FileInput(filename, inplace=True, backup='') as file:
         for line in file:
-            print(line.replace(search_text, replacement_text), end='')  
+            print(line.replace(search_text, replacement_text), end='')
+          
             
 def change_version_file(filepath, version, newversion):
     global path
@@ -245,7 +248,12 @@ def change_version_file(filepath, version, newversion):
         old_version = "version: {}".format(version)
         new_version = "version: {}".format(newversion)
         replace_version(filepath, old_version, new_version)  
-        
+    
+    if __main__.arch_type == 'maven': 
+        old_version = "<version>{}</version>".format(version)
+        new_version = "<version>{}</version>".format(newversion)
+        replace_version(filepath, old_version, new_version)
+     
     if __main__.arch_type == 'gradle':
         java_android_build_file = __main__.os.path.join(path, 'app/build.gradle')
         if __main__.os.path.exists(java_android_build_file):
@@ -263,8 +271,8 @@ def change_version_file(filepath, version, newversion):
             replace_version(filepath, old_version, new_version)        
             
     if __main__.arch_type == 'dotnet':
-        old_version = "<AssemblyVersion>{}</AssemblyVersion>".format(version)
-        new_version = "<AssemblyVersion>{}</AssemblyVersion>".format(newversion)
+        old_version = "AssemblyVersion(\"{}\")".format(version)
+        new_version = "AssemblyVersion(\"{}\")".format(newversion)
         replace_version(filepath, old_version, new_version)        
     
     if __main__.arch_type == 'netcore':
@@ -326,9 +334,16 @@ def modify_version():
             ## update versionCode and versionName
         else:
             version_file = 'build.gradle'
-            
+    if __main__.arch_type == 'maven':
+        version_file = 'pom.xml'      
     if __main__.arch_type == 'dotnet':
-        version_file = ''
+        file_list = glob('*.sln') 
+        if len(file_list) >= 1:
+            filename, filextension = __main__.os.path.splitext(file_list[0])
+            version_file = __main__.os.path.join(filename, filename, 'Properties', 'AssemblyInfo.cs') 
+        else:
+            print("ERROR: Could not file solution file (*.sln)")
+            return __main__.sys.exit(2)
     
     if __main__.arch_type == 'netcore':
         version_file = ''
